from checkov.terraform.checks.resource.aws import *
from checkov.terraform.checks.resource.gcp import *
from checkov.terraform.checks.resource.azure import *
from checkov.terraform.checks.resource.github import *
from checkov.terraform.checks.resource.linode import *
from checkov.terraform.checks.resource.oci import *
from checkov.terraform.checks.resource.openstack import *
from checkov.terraform.checks.resource.panos import *
from checkov.terraform.checks.resource.digitalocean import *
